Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r62421 - in sandbox/hash: boost/hash boost/hash/block_cyphers boost/hash/block_cyphers/detail boost/hash/detail libs/hash/doc/html libs/hash/example libs/hash/test
From: me22.ca+boost_at_[hidden]
Date: 2010-06-03 20:26:32


Author: smcmurray
Date: 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
New Revision: 62421
URL: http://svn.boost.org/trac/boost/changeset/62421

Log:
hash: change the namespace to boost::hashes to avoid a name collision with the boost::hash class template provided in boost/functional/hash.hpp
Text files modified:
   sandbox/hash/boost/hash/adler.hpp | 6 +++---
   sandbox/hash/boost/hash/block_cyphers/basic_shacal.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/basic_functions.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/md4_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/md5_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/shacal1_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/shacal2_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/shacal_functions.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/shacal_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/detail/threefish_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/md4.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/md5.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/shacal.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/shacal1.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/shacal2.hpp | 4 ++--
   sandbox/hash/boost/hash/block_cyphers/threefish.hpp | 4 ++--
   sandbox/hash/boost/hash/compute_digest.hpp | 4 ++--
   sandbox/hash/boost/hash/crc.hpp | 6 +++---
   sandbox/hash/boost/hash/cubehash.hpp | 4 ++--
   sandbox/hash/boost/hash/davies_meyer_compressor.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/basic_functions.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/cubehash_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/exploder.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/imploder.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/md4_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/md5_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/primes.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/sha1_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/sha2_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/sha_policy.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/state_adder.hpp | 4 ++--
   sandbox/hash/boost/hash/detail/unbounded_shift.hpp | 4 ++--
   sandbox/hash/boost/hash/digest.hpp | 4 ++--
   sandbox/hash/boost/hash/digest_io.hpp | 4 ++--
   sandbox/hash/boost/hash/md4.hpp | 4 ++--
   sandbox/hash/boost/hash/md5.hpp | 4 ++--
   sandbox/hash/boost/hash/merkle_damgard_block_hash.hpp | 6 +++---
   sandbox/hash/boost/hash/pack.hpp | 4 ++--
   sandbox/hash/boost/hash/sha.hpp | 4 ++--
   sandbox/hash/boost/hash/sha1.hpp | 4 ++--
   sandbox/hash/boost/hash/sha2.hpp | 4 ++--
   sandbox/hash/boost/hash/stream_endian.hpp | 4 ++--
   sandbox/hash/boost/hash/stream_preprocessor.hpp | 4 ++--
   sandbox/hash/libs/hash/doc/html/quickstart.html | 8 ++++----
   sandbox/hash/libs/hash/doc/html/rationale.html | 2 ++
   sandbox/hash/libs/hash/example/hashsum.cpp | 10 +++++-----
   sandbox/hash/libs/hash/example/quickstart.cpp | 2 +-
   sandbox/hash/libs/hash/test/adler.cpp | 8 ++++----
   sandbox/hash/libs/hash/test/crc.cpp | 6 +++---
   sandbox/hash/libs/hash/test/cubehash.cpp | 12 ++++++------
   sandbox/hash/libs/hash/test/cyphers.cpp | 2 +-
   sandbox/hash/libs/hash/test/digest.cpp | 6 +++---
   sandbox/hash/libs/hash/test/md.cpp | 2 +-
   sandbox/hash/libs/hash/test/pack.cpp | 4 ++--
   sandbox/hash/libs/hash/test/sha.cpp | 2 +-
   sandbox/hash/libs/hash/test/sha2.cpp | 2 +-
   sandbox/hash/libs/hash/test/shacal.cpp | 24 ++++++++++++------------
   sandbox/hash/libs/hash/test/threefish.cpp | 14 +++++++-------
   58 files changed, 142 insertions(+), 140 deletions(-)

Modified: sandbox/hash/boost/hash/adler.hpp
==============================================================================
--- sandbox/hash/boost/hash/adler.hpp (original)
+++ sandbox/hash/boost/hash/adler.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -19,7 +19,7 @@
 #endif
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 template <unsigned Bits>
 class basic_adler {
@@ -37,7 +37,7 @@
 
     typedef boost::array<word_type, 2> state_type;
 
- typedef hash::digest<digest_bits> digest_type;
+ typedef hashes::digest<digest_bits> digest_type;
 
     static word_type const modulo = detail::largest_prime<Bits/2>::value;
 
@@ -213,7 +213,7 @@
     typedef typename octet_hash_type::digest_type digest_type;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_ADLER_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/basic_shacal.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/basic_shacal.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/basic_shacal.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -31,7 +31,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 //
@@ -227,7 +227,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_BASIC_SHACAL_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/basic_functions.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/basic_functions.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/basic_functions.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/static_assert.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -57,7 +57,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_BASIC_FUNCTIONS_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/md4_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/md4_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/md4_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/block_cyphers/detail/basic_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -65,7 +65,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_MD4_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/md5_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/md5_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/md5_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/block_cyphers/detail/basic_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -100,7 +100,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_MD5_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/shacal1_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/shacal1_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/shacal1_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,7 +12,7 @@
 #include <boost/hash/block_cyphers/detail/shacal_policy.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -20,7 +20,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_SHACAL1_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/shacal2_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/shacal2_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/shacal2_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -15,7 +15,7 @@
 #include <boost/cstdint.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -133,7 +133,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_SHACAL2_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/shacal_functions.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/shacal_functions.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/shacal_functions.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,7 +12,7 @@
 #include <boost/hash/block_cyphers/detail/basic_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -89,7 +89,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_SHACAL_FUNCTIONS_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/shacal_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/shacal_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/shacal_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/block_cyphers/detail/shacal_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -66,7 +66,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_SHACAL_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/detail/threefish_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/detail/threefish_policy.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/detail/threefish_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/block_cyphers/detail/basic_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 namespace detail {
 
@@ -165,7 +165,7 @@
 
 } // namespace detail
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_DETAIL_THREEFISH_POLICY_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/md4.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/md4.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/md4.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -28,7 +28,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 class md4 {
@@ -205,7 +205,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_MD4_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/md5.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/md5.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/md5.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -28,7 +28,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 class md5 {
@@ -227,7 +227,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_MD5_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/shacal.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/shacal.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/shacal.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -23,7 +23,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 // The original FIPS-180 seems to be gone, but FIPS 180-1
@@ -68,7 +68,7 @@
 typedef shacal shacal0;
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_SHACAL_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/shacal1.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/shacal1.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/shacal1.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -23,7 +23,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 class shacal1 : public basic_shacal {
@@ -65,7 +65,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_SHACAL1_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/shacal2.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/shacal2.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/shacal2.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -30,7 +30,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 template <unsigned Version>
@@ -256,7 +256,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_SHACAL2_HPP

Modified: sandbox/hash/boost/hash/block_cyphers/threefish.hpp
==============================================================================
--- sandbox/hash/boost/hash/block_cyphers/threefish.hpp (original)
+++ sandbox/hash/boost/hash/block_cyphers/threefish.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -23,7 +23,7 @@
 //
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace block_cyphers {
 
 template <unsigned Version>
@@ -260,7 +260,7 @@
 };
 
 } // namespace block_cyphers
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_BLOCK_CYPHERS_THREEFISH_HPP

Modified: sandbox/hash/boost/hash/compute_digest.hpp
==============================================================================
--- sandbox/hash/boost/hash/compute_digest.hpp (original)
+++ sandbox/hash/boost/hash/compute_digest.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -21,7 +21,7 @@
 #include <cwchar>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 template <typename hash_T, typename iter_T>
 typename hash_T::digest_type
@@ -153,7 +153,7 @@
     return digest_computer_data<hash_T>();
 }
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_COMPUTE_DIGEST_HPP

Modified: sandbox/hash/boost/hash/crc.hpp
==============================================================================
--- sandbox/hash/boost/hash/crc.hpp (original)
+++ sandbox/hash/boost/hash/crc.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -22,7 +22,7 @@
 #endif
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 // Boost.CRC undefs this, so re-define it
 #define BOOST_CRC_PARM_TYPE typename ::boost::uint_t<Bits>::fast
@@ -43,7 +43,7 @@
     BOOST_STATIC_ASSERT(Bits >= value_bits);
 
     static unsigned const digest_bits = Bits;
- typedef hash::digest<digest_bits> digest_type;
+ typedef hashes::digest<digest_bits> digest_type;
 
   public:
     basic_crc() { reset(); }
@@ -149,7 +149,7 @@
 // http://www.libpng.org/pub/png/spec/1.2/PNG-Structure.html#CRC-algorithm
 typedef crc<32, 0x04C11DB7, 0xFFFFFFFF, 0xFFFFFFFF, true, true> crc32_png;
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_CRC_HPP

Modified: sandbox/hash/boost/hash/cubehash.hpp
==============================================================================
--- sandbox/hash/boost/hash/cubehash.hpp (original)
+++ sandbox/hash/boost/hash/cubehash.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -23,7 +23,7 @@
 #endif
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 template <unsigned r, unsigned b, unsigned h>
 struct cubehash_compressor {
@@ -127,7 +127,7 @@
             BOOST_HASH_CUBEHASH_DEFAULT_B,
             h> {};
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_CUBEHASH_HPP

Modified: sandbox/hash/boost/hash/davies_meyer_compressor.hpp
==============================================================================
--- sandbox/hash/boost/hash/davies_meyer_compressor.hpp (original)
+++ sandbox/hash/boost/hash/davies_meyer_compressor.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -10,7 +10,7 @@
 #define BOOST_HASH_DAVIES_MEYER_COMPRESSOR_HPP
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 //
 // The Davies-Meyer construction turns a block cypher
@@ -53,7 +53,7 @@
     }
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DAVIES_MEYER_COMPRESSOR_HPP

Modified: sandbox/hash/boost/hash/detail/basic_functions.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/basic_functions.hpp (original)
+++ sandbox/hash/boost/hash/detail/basic_functions.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,13 +12,13 @@
 #include <boost/hash/block_cyphers/detail/basic_functions.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 using block_cyphers::detail::basic_functions;
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_BASIC_FUNCTIONS_HPP

Modified: sandbox/hash/boost/hash/detail/cubehash_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/cubehash_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/cubehash_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -29,7 +29,7 @@
 #endif
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 //
@@ -466,7 +466,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_CUBEHASH_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/exploder.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/exploder.hpp (original)
+++ sandbox/hash/boost/hash/detail/exploder.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -20,7 +20,7 @@
 #include <cstring>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 // By definition, for all exploders, InputBits > OutputBits,
@@ -149,7 +149,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_EXPLODER_HPP

Modified: sandbox/hash/boost/hash/detail/imploder.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/imploder.hpp (original)
+++ sandbox/hash/boost/hash/detail/imploder.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <cstring>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 // By definition, for all imploders, InputBits < OutputBits,
@@ -129,7 +129,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_IMPLODER_HPP

Modified: sandbox/hash/boost/hash/detail/md4_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/md4_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/md4_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/digest.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 struct md4_policy {
@@ -37,7 +37,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_MD4_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/md5_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/md5_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/md5_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/digest.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 struct md5_policy {
@@ -38,7 +38,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_MD5_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/primes.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/primes.hpp (original)
+++ sandbox/hash/boost/hash/detail/primes.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,7 +12,7 @@
 #include <boost/integer.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 template <int Bits>
@@ -71,7 +71,7 @@
 BOOST_HASH_DEFINE_LARGEST_PRIME_BY_OFFSET(32, 4);
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_PRIMES_HPP

Modified: sandbox/hash/boost/hash/detail/sha1_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/sha1_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/sha1_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,13 +12,13 @@
 #include <boost/hash/detail/sha_policy.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 typedef sha_policy sha1_policy;
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_SHA1_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/sha2_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/sha2_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/sha2_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -15,7 +15,7 @@
 #include <boost/cstdint.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 template <unsigned CypherVersion>
@@ -112,7 +112,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_SHA2_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/sha_policy.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/sha_policy.hpp (original)
+++ sandbox/hash/boost/hash/detail/sha_policy.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/digest.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 struct sha_policy {
@@ -41,7 +41,7 @@
 typedef sha_policy sha0_policy;
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_SHA_POLICY_HPP

Modified: sandbox/hash/boost/hash/detail/state_adder.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/state_adder.hpp (original)
+++ sandbox/hash/boost/hash/detail/state_adder.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -10,7 +10,7 @@
 #define BOOST_HASH_DETAIL_STATE_ADDER_HPP
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 struct state_adder {
@@ -25,7 +25,7 @@
 };
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_STATE_ADDER_HPP

Modified: sandbox/hash/boost/hash/detail/unbounded_shift.hpp
==============================================================================
--- sandbox/hash/boost/hash/detail/unbounded_shift.hpp (original)
+++ sandbox/hash/boost/hash/detail/unbounded_shift.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,7 +12,7 @@
 #include <boost/assert.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 namespace detail {
 
 template <int N, typename T>
@@ -42,7 +42,7 @@
 }
 
 } // namespace detail
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DETAIL_UNBOUNDED_SHIFT_HPP

Modified: sandbox/hash/boost/hash/digest.hpp
==============================================================================
--- sandbox/hash/boost/hash/digest.hpp (original)
+++ sandbox/hash/boost/hash/digest.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -18,7 +18,7 @@
 #include <cstring>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 unsigned const octet_bits = 8;
 typedef uint_t<octet_bits>::least octet_type;
@@ -130,7 +130,7 @@
     return a == b;
 }
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DIGEST_HPP

Modified: sandbox/hash/boost/hash/digest_io.hpp
==============================================================================
--- sandbox/hash/boost/hash/digest_io.hpp (original)
+++ sandbox/hash/boost/hash/digest_io.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -19,7 +19,7 @@
 #include <cctype>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 template <unsigned DB>
 std::ostream &
@@ -54,7 +54,7 @@
     return source;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_DIGEST_IO_HPP

Modified: sandbox/hash/boost/hash/md4.hpp
==============================================================================
--- sandbox/hash/boost/hash/md4.hpp (original)
+++ sandbox/hash/boost/hash/md4.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <boost/hash/stream_preprocessor.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 struct md4 {
   private:
@@ -53,7 +53,7 @@
     typedef block_hash_type::digest_type digest_type;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_MD4_HPP

Modified: sandbox/hash/boost/hash/md5.hpp
==============================================================================
--- sandbox/hash/boost/hash/md5.hpp (original)
+++ sandbox/hash/boost/hash/md5.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <boost/hash/stream_preprocessor.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 struct md5 {
   private:
@@ -53,7 +53,7 @@
     typedef block_hash_type::digest_type digest_type;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_MD5_HPP

Modified: sandbox/hash/boost/hash/merkle_damgard_block_hash.hpp
==============================================================================
--- sandbox/hash/boost/hash/merkle_damgard_block_hash.hpp (original)
+++ sandbox/hash/boost/hash/merkle_damgard_block_hash.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,7 +13,7 @@
 #include <boost/hash/pack.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 //
 // The Merkle-DamgÃ¥rd construction builds a block hash from a
@@ -36,7 +36,7 @@
           typename finalizer_F = nop_finalizer>
 class merkle_damgard_block_hash {
   public:
- typedef hash::digest<digest_bits> digest_type;
+ typedef hashes::digest<digest_bits> digest_type;
 
     typedef iv_G iv_generator;
     typedef compressor_F compressor_functor;
@@ -86,7 +86,7 @@
     state_type state_;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_MERKLE_DAMGARD_BLOCK_HASH_HPP

Modified: sandbox/hash/boost/hash/pack.hpp
==============================================================================
--- sandbox/hash/boost/hash/pack.hpp (original)
+++ sandbox/hash/boost/hash/pack.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -21,7 +21,7 @@
 #endif
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 #ifndef BOOST_HASH_NO_OPTIMIZATION
 
@@ -294,7 +294,7 @@
                                                   out.data(), out.size());
 }
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_PACK_HPP

Modified: sandbox/hash/boost/hash/sha.hpp
==============================================================================
--- sandbox/hash/boost/hash/sha.hpp (original)
+++ sandbox/hash/boost/hash/sha.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <boost/hash/stream_preprocessor.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 struct sha {
   private:
@@ -54,7 +54,7 @@
 };
 typedef sha sha0;
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_SHA_HPP

Modified: sandbox/hash/boost/hash/sha1.hpp
==============================================================================
--- sandbox/hash/boost/hash/sha1.hpp (original)
+++ sandbox/hash/boost/hash/sha1.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <boost/hash/stream_preprocessor.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 struct sha1 {
   private:
@@ -53,7 +53,7 @@
     typedef block_hash_type::digest_type digest_type;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_SHA1_HPP

Modified: sandbox/hash/boost/hash/sha2.hpp
==============================================================================
--- sandbox/hash/boost/hash/sha2.hpp (original)
+++ sandbox/hash/boost/hash/sha2.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -17,7 +17,7 @@
 #include <boost/hash/stream_preprocessor.hpp>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 template <unsigned Version>
 struct sha2 {
@@ -55,7 +55,7 @@
     typedef typename block_hash_type::digest_type digest_type;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_SHA2_HPP

Modified: sandbox/hash/boost/hash/stream_endian.hpp
==============================================================================
--- sandbox/hash/boost/hash/stream_endian.hpp (original)
+++ sandbox/hash/boost/hash/stream_endian.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -14,7 +14,7 @@
 #include <climits>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 namespace stream_endian {
 
@@ -51,7 +51,7 @@
 
 }
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_STREAM_ENDIAN_HPP

Modified: sandbox/hash/boost/hash/stream_preprocessor.hpp
==============================================================================
--- sandbox/hash/boost/hash/stream_preprocessor.hpp (original)
+++ sandbox/hash/boost/hash/stream_preprocessor.hpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -18,7 +18,7 @@
 #include <iterator>
 
 namespace boost {
-namespace hash {
+namespace hashes {
 
 //
 // This will do the usual Merkle-DamgÃ¥rd-style strengthening, padding with
@@ -209,7 +209,7 @@
     length_type seen;
 };
 
-} // namespace hash
+} // namespace hashes
 } // namespace boost
 
 #endif // BOOST_HASH_STREAM_PREPROCESSOR_HPP

Modified: sandbox/hash/libs/hash/doc/html/quickstart.html
==============================================================================
--- sandbox/hash/libs/hash/doc/html/quickstart.html (original)
+++ sandbox/hash/libs/hash/doc/html/quickstart.html 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -19,7 +19,7 @@
     <TR>
     <TH>Name
     <TH>Digest Bits
- <TH>HashAlgorithm Model (in <tt>boost::hash</tt>)
+ <TH>HashAlgorithm Model (in <tt>boost::hashes</tt>)
     <TH>Reference
     <TH>Design Type
     <TH>Notes
@@ -109,7 +109,7 @@
     </TABLE>
 If you need security against a malicious adversary, <tt>sha2&lt;<i>h</i>&gt;</tt> is, as of 2010, the recommended choice. If not, then two popular choices are <tt>crc&lt;<i>h</i>&gt;</tt> for checksums and <tt>md5</tt> for fingerprinting.
 
-<LI>With the chosen <i>HashAlgorithm</i>, call the <tt>boost::hash::compute_digest&lt;<i>HashAlgorithm</i>&gt;</tt> function, passing it an input range (such as a container). That will return the digest as an object of type <tt><i>HashAlgorithm</i>::digest_type</tt>.
+<LI>With the chosen <i>HashAlgorithm</i>, call the <tt>boost::hashes::compute_digest&lt;<i>HashAlgorithm</i>&gt;</tt> function, passing it an input range (such as a container). That will return the digest as an object of type <tt><i>HashAlgorithm</i>::digest_type</tt>.
 
 <LI>The resulting digest may then be output to a <tt>std::ostream</tt> or compared against other message digests (such as one read from a <tt>std::istream</tt>).
 
@@ -127,9 +127,9 @@
 }
 
 int main() {
- using namespace boost::hash;
+ using namespace boost::hashes;
     std::string s = "Hello World!";
- typedef boost::hash::sha2&lt;256&gt; HashAlgorithm;
+ typedef sha2&lt;256&gt; HashAlgorithm;
     HashAlgorithm::digest_type digest = compute_digest&lt;HashAlgorithm&gt;(s);
     std::cout &lt;&lt; digest &lt;&lt; "\n";
 }

Modified: sandbox/hash/libs/hash/doc/html/rationale.html
==============================================================================
--- sandbox/hash/libs/hash/doc/html/rationale.html (original)
+++ sandbox/hash/libs/hash/doc/html/rationale.html 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -11,6 +11,8 @@
 
 <P>On the implementation side, hash algorithms are build out of smaller components (see, for instance, the Davies-Meyer and Merkle-Damgård constructions) in a way which provides for an elegant generic implementation. Generic programming also allows them to accept a wide range of input sizes, instead of just allowing byte-oriented input like the vast majority of other implementations.
 
+<P>The namespace <tt>hashes</tt> is used because <tt>boost::hash</tt> is a class template provided by <tt>boost/functional/hash.hpp</tt> for use with unordered containers.
+
 <P><TABLE WIDTH="100%">
 <TR>
 <TD>Previous: Validation</TD>

Modified: sandbox/hash/libs/hash/example/hashsum.cpp
==============================================================================
--- sandbox/hash/libs/hash/example/quickstart.cpp (original)
+++ sandbox/hash/libs/hash/example/quickstart.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -12,7 +12,7 @@
 #include <string>
 
 int main() {
- using namespace boost::hash;
+ using namespace boost::hashes;
     std::string s = "Hello World!";
     typedef sha2<256> HashAlgorithm;
     HashAlgorithm::digest_type digest = compute_digest<HashAlgorithm>(s);

Modified: sandbox/hash/libs/hash/test/adler.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/adler.cpp (original)
+++ sandbox/hash/libs/hash/test/adler.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -11,7 +11,7 @@
 #include <cassert>
 
 namespace primes_check {
- using boost::hash::detail::largest_prime;
+ using boost::hashes::detail::largest_prime;
 
     BOOST_STATIC_ASSERT(largest_prime< 2>::value == 3);
     BOOST_STATIC_ASSERT(largest_prime< 3>::value == 7);
@@ -49,8 +49,8 @@
 }
 
 void test32() {
- typedef boost::hash::adler<32> HASH;
- using boost::hash::compute_digest;
+ typedef boost::hashes::adler<32> HASH;
+ using boost::hashes::compute_digest;
 
     {
     HASH::digest_type d = compute_digest<HASH>("\x2");
@@ -143,7 +143,7 @@
 }
 
 int main() {
- using namespace boost::hash;
+ using namespace boost::hashes;
 
     test32();
     

Modified: sandbox/hash/libs/hash/test/crc.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/crc.cpp (original)
+++ sandbox/hash/libs/hash/test/crc.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -9,8 +9,8 @@
 #include <cassert>
 
 void test32() {
- typedef boost::hash::crc32_png HASH;
- using boost::hash::compute_digest;
+ typedef boost::hashes::crc32_png HASH;
+ using boost::hashes::compute_digest;
 
     // Messages from MD4/MD5 test vectors
     
@@ -93,7 +93,7 @@
 }
 
 int main() {
- using namespace boost::hash;
+ using namespace boost::hashes;
 
     test32();
     

Modified: sandbox/hash/libs/hash/test/cubehash.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/cubehash.cpp (original)
+++ sandbox/hash/libs/hash/test/cubehash.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -14,7 +14,7 @@
 
     {
     // Test of just the policy, equivalent to hashing an empty message
- typedef boost::hash::detail::cubehash_policy<16, 32, 512> policy_type;
+ typedef boost::hashes::detail::cubehash_policy<16, 32, 512> policy_type;
     policy_type::state_type s = policy_type::iv_generator()();
     printf("initial s[0] = %.8x\n", s[0]);
     assert(s[0] == 0x2aea2a61);
@@ -29,7 +29,7 @@
     }
 
     {
- typedef boost::hash::cubehash<16, 32, 512> hash;
+ typedef boost::hashes::cubehash<16, 32, 512> hash;
     typedef hash::block_hash_type bht;
     bht bh;
     printf("initial s[0] = %.8x\n", bh.state()[0]);
@@ -46,8 +46,8 @@
     }
 
     {
- typedef boost::hash::cubehash<16, 32, 512> hash;
- using boost::hash::compute_digest;
+ typedef boost::hashes::cubehash<16, 32, 512> hash;
+ using boost::hashes::compute_digest;
     hash::stream_hash<8>::type sh;
     hash::digest_type d;
 
@@ -124,8 +124,8 @@
     }
 
     {
- typedef boost::hash::cubehash<16, 32, 256> hash;
- using boost::hash::compute_digest;
+ typedef boost::hashes::cubehash<16, 32, 256> hash;
+ using boost::hashes::compute_digest;
     hash::stream_hash<8>::type sh;
     hash::digest_type d;
 

Modified: sandbox/hash/libs/hash/test/cyphers.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/cyphers.cpp (original)
+++ sandbox/hash/libs/hash/test/cyphers.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -56,7 +56,7 @@
 }
 
 int main() {
- using namespace boost::hash::block_cyphers;
+ using namespace boost::hashes::block_cyphers;
     test_block_cypher<md4>();
     test_block_cypher<md5>();
     test_block_cypher<shacal>();

Modified: sandbox/hash/libs/hash/test/digest.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/digest.cpp (original)
+++ sandbox/hash/libs/hash/test/digest.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -8,7 +8,7 @@
 #include <cassert>
 
 int main() {
- using boost::hash::digest;
+ using boost::hashes::digest;
 
     {
     std::stringstream ss;
@@ -39,8 +39,8 @@
     }
 
     {
- using boost::hash::truncate;
- using boost::hash::resize;
+ using boost::hashes::truncate;
+ using boost::hashes::resize;
     std::stringstream ss("0123456789abcdeffedcba9876543210");
     digest<32*4> d;
     ss >> d;

Modified: sandbox/hash/libs/hash/test/md.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/md.cpp (original)
+++ sandbox/hash/libs/hash/test/md.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -8,7 +8,7 @@
 #include <cstdio>
 #include <cstring>
 
-using namespace boost::hash;
+using namespace boost::hashes;
 
 void test_accumulator_md4() {
     md4::block_hash_type a;

Modified: sandbox/hash/libs/hash/test/pack.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/pack.cpp (original)
+++ sandbox/hash/libs/hash/test/pack.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -13,8 +13,8 @@
 using boost::int8_t;
 using boost::int16_t;
 using boost::int32_t;
-using namespace boost::hash;
-using namespace boost::hash::stream_endian;
+using namespace boost::hashes;
+using namespace boost::hashes::stream_endian;
 
 void test_explodebb() {
 

Modified: sandbox/hash/libs/hash/test/sha.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/sha.cpp (original)
+++ sandbox/hash/libs/hash/test/sha.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -10,7 +10,7 @@
 #include <cstring>
 #include <boost/cstdint.hpp>
 
-using namespace boost::hash;
+using namespace boost::hashes;
 
 //
 // Appendix references are from

Modified: sandbox/hash/libs/hash/test/sha2.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/sha2.cpp (original)
+++ sandbox/hash/libs/hash/test/sha2.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -7,7 +7,7 @@
 #include <cstdio>
 #include <cstring>
 
-using namespace boost::hash;
+using namespace boost::hashes;
 
 //
 // Appendix references are from

Modified: sandbox/hash/libs/hash/test/shacal.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/shacal.cpp (original)
+++ sandbox/hash/libs/hash/test/shacal.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -25,7 +25,7 @@
 };
 
 void test_shacal1_block_cypher() {
- typedef boost::hash::block_cyphers::shacal1 bct;
+ typedef boost::hashes::block_cyphers::shacal1 bct;
 
     {
     // Test with the equivalent of SHA-1("")
@@ -49,7 +49,7 @@
     assert(plaintext == new_plaintext);
     }
 
- typedef boost::hash::davies_meyer_compressor<bct, state_adder> owcft;
+ typedef boost::hashes::davies_meyer_compressor<bct, state_adder> owcft;
 
     {
     // Test with the equivalent of SHA-256("")
@@ -71,10 +71,10 @@
     assert(H == H1);
     }
 
- typedef boost::hash::merkle_damgard_block_hash<
- boost::hash::stream_endian::big_octet_big_bit,
+ typedef boost::hashes::merkle_damgard_block_hash<
+ boost::hashes::stream_endian::big_octet_big_bit,
                 160,
- boost::hash::detail::sha1_policy::iv_generator,
+ boost::hashes::detail::sha1_policy::iv_generator,
                 owcft
> bht;
 
@@ -92,7 +92,7 @@
 }
 
 void test_shacal256_block_cypher() {
- typedef boost::hash::block_cyphers::shacal2<256> bct;
+ typedef boost::hashes::block_cyphers::shacal2<256> bct;
 
     {
     // Test with the equivalent of SHA-256("")
@@ -125,7 +125,7 @@
     assert(plaintext == new_plaintext);
     }
 
- typedef boost::hash::davies_meyer_compressor<bct, state_adder> owcft;
+ typedef boost::hashes::davies_meyer_compressor<bct, state_adder> owcft;
 
     {
     // Test with the equivalent of SHA-256("")
@@ -156,10 +156,10 @@
     assert(H == H1);
     }
 
- typedef boost::hash::merkle_damgard_block_hash<
- boost::hash::stream_endian::big_octet_big_bit,
+ typedef boost::hashes::merkle_damgard_block_hash<
+ boost::hashes::stream_endian::big_octet_big_bit,
                 256,
- boost::hash::detail::sha2_policy<256>::iv_generator,
+ boost::hashes::detail::sha2_policy<256>::iv_generator,
                 owcft
> bht;
 
@@ -177,7 +177,7 @@
 }
 
 void test_sha1() {
- using namespace boost::hash;
+ using namespace boost::hashes;
     typedef merkle_damgard_block_hash<
                 stream_endian::big_octet_big_bit,
                 160,
@@ -208,7 +208,7 @@
 }
 
 void test_sha512() {
- using namespace boost::hash;
+ using namespace boost::hashes;
     unsigned const SHA = 512;
     typedef merkle_damgard_block_hash<
                 stream_endian::big_octet_big_bit,

Modified: sandbox/hash/libs/hash/test/threefish.cpp
==============================================================================
--- sandbox/hash/libs/hash/test/threefish.cpp (original)
+++ sandbox/hash/libs/hash/test/threefish.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -9,7 +9,7 @@
 
 template <typename digest_type, typename state_type>
 digest_type to_digest(state_type state) {
- using namespace boost::hash;
+ using namespace boost::hashes;
     int const digest_bits = digest_type::digest_bits;
     int const word_bits = 64;
     digest_type d;
@@ -23,11 +23,11 @@
 // All test vectors are from skein_golden_kat_internals.txt
 
 void test_256() {
- typedef boost::hash::block_cyphers::threefish<256> cypher_type;
+ typedef boost::hashes::block_cyphers::threefish<256> cypher_type;
     typedef cypher_type::key_type key_type;
     typedef cypher_type::tweak_type tweak_type;
     typedef cypher_type::block_type block_type;
- typedef boost::hash::digest<cypher_type::block_bits> digest_type;
+ typedef boost::hashes::digest<cypher_type::block_bits> digest_type;
 
     {
     // All-zero key, tweak, and plaintext
@@ -74,11 +74,11 @@
 }
 
 void test_512() {
- typedef boost::hash::block_cyphers::threefish<512> cypher_type;
+ typedef boost::hashes::block_cyphers::threefish<512> cypher_type;
     typedef cypher_type::key_type key_type;
     typedef cypher_type::tweak_type tweak_type;
     typedef cypher_type::block_type block_type;
- typedef boost::hash::digest<cypher_type::block_bits> digest_type;
+ typedef boost::hashes::digest<cypher_type::block_bits> digest_type;
 
     {
     // All-zero key, tweak, and plaintext
@@ -135,11 +135,11 @@
 }
 
 void test_1024() {
- typedef boost::hash::block_cyphers::threefish<1024> cypher_type;
+ typedef boost::hashes::block_cyphers::threefish<1024> cypher_type;
     typedef cypher_type::key_type key_type;
     typedef cypher_type::tweak_type tweak_type;
     typedef cypher_type::block_type block_type;
- typedef boost::hash::digest<cypher_type::block_bits> digest_type;
+ typedef boost::hashes::digest<cypher_type::block_bits> digest_type;
 
     {
     // All-zero key, tweak, and plaintext


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/hash/libs/hash/example/hashsum.cpp (original)
+++ sandbox/hash/libs/hash/example/hashsum.cpp 2010-06-03 20:26:27 EDT (Thu, 03 Jun 2010)
@@ -8,7 +8,7 @@
 
 //
 // Define HASH to one of the models of the HashAlgorithm concept.
// Do not include the boost::hash:: namespace qualifier.
 //
 
 #ifndef HASH
@@ -30,12 +30,12 @@
 #include <sys/mman.h>
 #endif
 
-typedef boost::hash::HASH HashAlgorithm;
+typedef boost::hashes::HASH HashAlgorithm;
 
 HashAlgorithm::digest_type
 hash_streambuf(std::streambuf *sbuf) {
 #ifdef BOOST_HASH_NO_OPTIMIZATION
- return boost::hash::compute_digest<HashAlgorithm>(
+ return boost::hashes::compute_digest<HashAlgorithm>(
                std::istreambuf_iterator<char>(sbuf),
                std::istreambuf_iterator<char>()
            );
@@ -53,7 +53,7 @@
 
 HashAlgorithm::digest_type
 hash_memory(void *buf, size_t n) {
- return boost::hash::compute_digest_n<HashAlgorithm>((char*)buf, n);
+ return boost::hashes::compute_digest_n<HashAlgorithm>((char*)buf, n);
 }
 
 std::ostream &
@@ -84,7 +84,7 @@
 }
 
 int main(int argc, char **argv) {
- std::cerr << "Using boost::hash::" XSTR(HASH) "\n";
+ std::cerr << "Using boost::hashes::" XSTR(HASH) "\n";
     if (argc < 2) {
         do_istream(std::cout, "-", std::cin);
     } else {
@@ -8,7 +8,7 @@
 //
 // Define HASH to one of the models of the HashAlgorithm concept.
-// Do not include the boost::hash:: namespace qualifier.
+// Do not include the boost::hashes:: namespace qualifier.
 //
 

Modified: sandbox/hash/libs/hash/example/quickstart.cpp
==============================================================================